<?php

namespace Pinpoint\OrderShare\Block\Success;

use Magento\Framework\View\Element\Template;

/**
 * Class Socials
 * @package Pinpoint\OrderShare\Block\Success
 */
class Socials extends Template
{
    /**
     * @var \Pinpoint\OrderShare\Helper\Data
     */
    protected $dataHelper;

    /**
     * @var \Magento\Checkout\Model\Session
     */
    protected $checkoutSession;

    /**
     * @var \Magento\Sales\Model\OrderFactory
     */
    protected $orderFactory;

    /**
     * @var string
     */
    const ENABLED_SOCIAL_CONFIG_PATH = 'pinpoint_ordershare/module_settings/enabled_share_outlets';

    /**
     * @var string
     */
    const SOCIAL_SHOW_LABEL_CONFIG_PATH = 'pinpoint_ordershare/module_settings/share_show_label';

    /**
     * @var string
     */
    const SOCIAL_SHOW_COUNT_CONFIG_PATH = 'pinpoint_ordershare/module_settings/share_show_count';

    /**
     * @var string
     */
    const SOCIAL_CUSTOM_LOGO_CONFIG_PATH = 'pinpoint_ordershare/custom_icons/';

    /**
     * Socials constructor.
     * @param Template\Context $context
     * @param \Pinpoint\OrderShare\Helper\Data $dataHelper
     * @param \Magento\Checkout\Model\Session $checkoutSession
     * @param \Magento\Sales\Model\OrderFactory $orderFactory
     * @param array $data
     */
    public function __construct(
        Template\Context $context,
        \Pinpoint\OrderShare\Helper\Data $dataHelper,
        \Magento\Checkout\Model\Session $checkoutSession,
        \Magento\Sales\Model\OrderFactory $orderFactory,
        array $data = []
    ) {
        $this->dataHelper = $dataHelper;
        $this->checkoutSession = $checkoutSession;
        $this->orderFactory = $orderFactory;

        parent::__construct($context, $data);
    }

    /**
     * @return array
     */
    public function getEnabledSocials()
    {
        $enabled = $this->_scopeConfig->getValue(self::ENABLED_SOCIAL_CONFIG_PATH);
        $socials = [];
        if ($enabled) {
            $socials = ['jsSocials' => explode(',', $enabled)];

            if (($key = array_search('skype', $socials['jsSocials'])) !== false) {
                $socials['skype'] = true;
                unset($socials['jsSocials'][$key]);
            } else {
                $socials['skype'] = false;
            }
        }

        return $socials;
    }

    /**
     * @return \Magento\Framework\Phrase
     */
    public function getShareText()
    {
        $order = $this->getOrder();

        $mostExpensive = $order->getItemsCollection()->setOrder('price', 'desc')->getFirstItem();

        $shareText = "I've just bought %1%2 from";

        return __(
            $shareText,
            $mostExpensive->getName(),
            $order->getItemsCollection()->count() > 1 ? ', and more':''
        );
    }

    /**
     * @param $social
     * @return int
     */
    public function showLabel($social)
    {
        $socials = explode(',', $this->_scopeConfig->getValue(self::SOCIAL_SHOW_LABEL_CONFIG_PATH));

        return in_array($social, $socials)?:0;
    }

    /**
     * @param $social
     * @return int
     */
    public function showCount($social)
    {
        if ($social === 'twitter') {
            return 0;
        }

        $socials = explode(',', $this->_scopeConfig->getValue(self::SOCIAL_SHOW_COUNT_CONFIG_PATH));

        return in_array($social, $socials)?:0;
    }

    /**
     * @param $social
     * @return null|string
     */
    public function getCustomLogo($social)
    {
        if ($logo = $this->_scopeConfig->getValue(self::SOCIAL_CUSTOM_LOGO_CONFIG_PATH . $social . '_icon')) {
            return $this->_storeManager->getStore()->getBaseUrl(\Magento\Framework\UrlInterface::URL_TYPE_MEDIA)
                . \Pinpoint\OrderShare\Model\Config\Backend\Image::UPLOAD_DIR
                . DIRECTORY_SEPARATOR
                . $logo;
        }

        return null;
    }

    /**
     * @return \Magento\Sales\Model\Order
     */
    protected function getOrder()
    {
        $order = $this->orderFactory->create()->load(
            $this->checkoutSession->getLastRealOrder()->getIncrementId()
        );

        return $order;
    }
}